# Changelog

## 1.0.0 (2025-06-19)

Full Changelog: [v0.0.1-alpha.0...v1.0.0](https://github.com/mwe1/millionways-python-sdk/compare/v0.0.1-alpha.0...v1.0.0)

### Chores

* update SDK settings ([6e056ee](https://github.com/mwe1/millionways-python-sdk/commit/6e056eecbe231ef7dd57178881db0403f9bc4ed7))
* update SDK settings ([93830d6](https://github.com/mwe1/millionways-python-sdk/commit/93830d6d621097004e11263ffdeec2e1483ef6ea))
